@@ -2,9 +2,25 @@ package gtree
 
 import "context"
 
+// Definition of optional functions for Node.
+type NodeOption func(*Node)
+
+// WithDuplicationAllowed is an optional function that ensures Add method call creates and returns a new node even if a node with the same text already exists at the same hierarchy. It can be specified in the NewRoot function.
+func WithDuplicationAllowed() NodeOption {
+	return func(n *Node) {
+		n.allowDuplicates = true
+	}
+}
+
 type config struct {
-	lastNodeFormat        branchFormat
-	intermedialNodeFormat branchFormat
+	lastBranch string
+	midBranch  string
+	hLine      string
+	vLine      string
+
+	// todo: refactor
+	lastNodeFormat        *branchFormat
+	intermedialNodeFormat *branchFormat
 
 	massive        bool
 	ctx            context.Context
@@ -19,17 +35,15 @@ type config struct {
 
 func newConfig(options []Option) *config {
 	c := &config{
-		lastNodeFormat: branchFormat{
-			directly:   "└──",
-			indirectly: "    ",
-		},
-		intermedialNodeFormat: branchFormat{
-			directly:   "├──",
-			indirectly: "│   ",
-		},
-		massive:   false,
-		encode:    encodeDefault,
-		targetDir: ".",
+		lastBranch:            "└",
+		midBranch:             "├",
+		hLine:                 "──",
+		vLine:                 "│",
+		lastNodeFormat:        &branchFormat{},
+		intermedialNodeFormat: &branchFormat{},
+		massive:               false,
+		encode:                encodeDefault,
+		targetDir:             ".",
 	}
 	for _, opt := range options {
 		if opt == nil {
@@ -37,25 +51,41 @@ func newConfig(options []Option) *config {
 		}
 		opt(c)
 	}
+	c.lastNodeFormat.directly = c.lastBranch + c.hLine
+	c.lastNodeFormat.indirectly = "    "
+	c.intermedialNodeFormat.directly = c.midBranch + c.hLine
+	c.intermedialNodeFormat.indirectly = c.vLine + "   "
 	return c
 }
 
 // Option is functional options pattern
 type Option func(*config)
 
-// WithBranchFormatIntermedialNode returns function for branch format.
-func WithBranchFormatIntermedialNode(directly, indirectly string) Option {
+// WithLastBranch allows you to change the branch parts.
+func WithLastBranch(s string) Option {
 	return func(c *config) {
-		c.intermedialNodeFormat.directly = directly
-		c.intermedialNodeFormat.indirectly = indirectly
+		c.lastBranch = s
 	}
 }
 
-// WithBranchFormatLastNode returns function for branch format.
-func WithBranchFormatLastNode(directly, indirectly string) Option {
+// WithMidBranch allows you to change the branch parts.
+func WithMidBranch(s string) Option {
 	return func(c *config) {
-		c.lastNodeFormat.directly = directly
-		c.lastNodeFormat.indirectly = indirectly
+		c.midBranch = s
+	}
+}
+
+// WithHLine allows you to change the branch parts.
+func WithHLine(s string) Option {
+	return func(c *config) {
+		c.hLine = s
+	}
+}
+
+// WithVLine allows you to change the branch parts.
+func WithVLine(s string) Option {
+	return func(c *config) {
+		c.vLine = s
 	}
 }
 
